@@ -346,6 +346,9 @@ class GatewayApi(tornado.web.RequestHandler):
                 # 这些状态下response中不能有body，所以不应该write
                 return
 
+            if self._headers.get('Content-Length') is not None:
+                self.set_header('Content-Length', len(response.content))
+
             self.write(response.content)
         else:
             self.set_status(500)
